@@ -18,14 +18,16 @@ package config
 
 import (
 	"path/filepath"
+	"strings"
 
 	"github.com/accurics/terrascan/pkg/utils"
 	"go.uber.org/zap"
 )
 
 const (
-	defaultPolicyRepoURL = "https://github.com/accurics/terrascan.git"
-	defaultPolicyBranch  = "master"
+	defaultPolicyRepoURL     = "https://github.com/accurics/terrascan.git"
+	defaultPolicyBranch      = "master"
+	defaultPolicyEnvironment = "https://cloud.tenable.com"
 )
 
 // ConfigEnvvarName env variable
@@ -92,6 +94,12 @@ func LoadGlobalConfig(configFile string) error {
 	if len(configReader.getPolicyConfig().Branch) > 0 {
 		global.Policy.Branch = configReader.getPolicyConfig().Branch
 	}
+	if len(configReader.getPolicyConfig().Environment) > 0 {
+		global.Policy.Environment = configReader.getPolicyConfig().Environment
+	}
+	if len(configReader.getPolicyConfig().AccessToken) > 0 {
+		global.Policy.AccessToken = configReader.getPolicyConfig().AccessToken
+	}
 
 	if len(configReader.getRules().ScanRules) > 0 {
 		global.Rules.ScanRules = configReader.getRules().ScanRules
@@ -152,6 +160,22 @@ func GetPolicyBranch() string {
 	return global.Policy.Branch
 }
 
+// GetPolicyEnvironment returns the configured policy environment url
+func GetPolicyEnvironment() string {
+	if global == nil {
+		return defaultPolicyEnvironment
+	}
+	return strings.TrimRight(global.Policy.Environment, "/")
+}
+
+// GetPolicyAccessToken returns the configured policy access token
+func GetPolicyAccessToken() string {
+	if global == nil {
+		return ""
+	}
+	return global.Policy.AccessToken
+}
+
 // GetScanRules returns the configured scan rules
 func GetScanRules() []string {
 	if global == nil {
