@@ -37,14 +37,14 @@ func TestLoadIacDir(t *testing.T) {
 	destroyProvisionersDir := filepath.Join(testDataDir, "destroy-provisioners")
 	destroyProvisionersMainFile := filepath.Join(destroyProvisionersDir, "main.tf")
 
-	testErrorString1 := fmt.Sprintf(`failed to load terraform config dir '%s'. error from terraform:
+	testErrorString1 := fmt.Sprintf(`diagnostic errors while loading terraform config dir '%s'. error from terraform:
 %s:1,21-2,1: Invalid block definition; A block definition must have block content delimited by "{" and "}", starting on the same line as the block header.
 %s:1,1-5: Unsupported block type; Blocks of type "some" are not expected here.
 `, testDataDir, emptyTfFilePath, emptyTfFilePath)
 
 	multipleProvidersDir := filepath.Join(testDataDir, "multiple-required-providers")
 
-	testErrorString2 := fmt.Sprintf(`failed to load terraform config dir '%s'. error from terraform:
+	testErrorString2 := fmt.Sprintf(`diagnostic errors while loading terraform config dir '%s'. error from terraform:
 %s:2,3-21: Duplicate required providers configuration; A module may have only one required providers configuration. The required providers were previously configured at %s:2,3-21.
 `, multipleProvidersDir, filepath.Join(multipleProvidersDir, "b.tf"), filepath.Join(multipleProvidersDir, "a.tf"))
 
@@ -52,7 +52,7 @@ func TestLoadIacDir(t *testing.T) {
 <nil>: Failed to read module directory; Module directory %s does not exist or cannot be read.
 `, filepath.Join(testDataDir, "invalid-moduleconfigs", "cloudfront", "sub-cloudfront"))
 
-	errStringDestroyProvisioners := fmt.Sprintf(`failed to load terraform config dir '%s'. error from terraform:
+	errStringDestroyProvisioners := fmt.Sprintf(`diagnostic errors while loading terraform config dir '%s'. error from terraform:
 %s:8,12-22: Invalid reference from destroy provisioner; Destroy-time provisioners and their connection configurations may only reference attributes of the related resource, via 'self', 'count.index', or 'each.key'.
 
 References to other resources during the destroy phase can cause dependency cycles and interact poorly with create_before_destroy.
