@@ -20,7 +20,7 @@ import (
 	"encoding/json"
 	"fmt"
 
-	"github.com/awslabs/goformation/v4/cloudformation/iam"
+	"github.com/awslabs/goformation/v5/cloudformation/iam"
 )
 
 const (
@@ -35,6 +35,12 @@ type IamGroupPolicyConfig struct {
 	PolicyDocument string `json:"policy"`
 }
 
+// IamGroupConfig holds config for aws_iam_group
+type IamGroupConfig struct {
+	Config
+	Name string `json:"name"`
+}
+
 // GetIamGroupConfig returns config for aws_iam_group_policy
 func GetIamGroupConfig(r *iam.Group) []AWSResourceConfig {
 	// aws_iam_role_policy as a SubResource
@@ -61,5 +67,17 @@ func GetIamGroupConfig(r *iam.Group) []AWSResourceConfig {
 		}
 	}
 
+	groupConfig := IamGroupConfig{
+		Config: Config{
+			Name: r.GroupName,
+		},
+		Name: r.GroupName,
+	}
+
+	var groupPolicyConfig AWSResourceConfig
+	groupPolicyConfig.Resource = groupConfig
+	groupPolicyConfig.Metadata = r.AWSCloudFormationMetadata
+	policyConfigs = append(policyConfigs, groupPolicyConfig)
+
 	return policyConfigs
 }
