@@ -24,10 +24,15 @@ const (
 	AwsAPIGatewayStage               = "aws_api_gateway_stage"
 	AwsAPIGatewayStageMethodSettings = "aws_api_gateway_method_settings"
 	AwsAPIGatewayV2Stage             = "aws_apigatewayv2_stage"
+	AwsAPIGatewayV2Api               = "aws_apigatewayv2_api"
+	AwsAthenaWorkGroup               = "aws_athena_workgroup"
+	AwsQldbLedger                    = "aws_qldb_ledger"
 	AwsEcsService                    = "aws_ecs_service"
+	AwsEcsCluster                    = "aws_ecs_cluster"
 	AwsDynamoDBTable                 = "aws_dynamodb_table"
 	AwsDaxCluster                    = "aws_dax_cluster"
 	AwsDBInstance                    = "aws_db_instance"
+	AwsDBEventSubscription           = "aws_db_event_subscription"
 	AwsIamRole                       = "aws_iam_role"
 	AwsIamRolePolicy                 = "aws_iam_role_policy"
 	AwsIamGroup                      = "aws_iam_group"
@@ -43,6 +48,8 @@ const (
 	AwsElastiCacheCluster            = "aws_elasticache_cluster"
 	AwsElastiCacheReplicationGroup   = "aws_elasticache_replication_group"
 	AwsGuardDutyDetector             = "aws_guardduty_detector"
+	AwsGlobalAcceleratorAccelerator  = "aws_globalaccelerator_accelerator"
+	AwsWafSizeConstraintSet          = "aws_waf_size_constraint_set"
 	AwsMqBroker                      = "aws_mq_broker"
 	AwsRedshiftCluster               = "aws_redshift_cluster"
 	AwsRedshiftParameterGroup        = "aws_redshift_parameter_group"
@@ -64,6 +71,7 @@ const (
 	AwsConfigConfigurationAggregator = "aws_config_configuration_aggregator"
 	AwsLbListener                    = "aws_lb_listener"
 	AwsLbTargetGroup                 = "aws_lb_target_group"
+	AwsNeptuneClusterInstance        = "aws_neptune_cluster_instance"
 	AwsElb                           = "aws_elb"
 	AwsElbPolicy                     = "aws_load_balancer_policy"
 	AwsElasticsearchDomain           = "aws_elasticsearch_domain"
