@@ -17,7 +17,6 @@
 package writer
 
 import (
-	"fmt"
 	"github.com/accurics/terrascan/pkg/policy"
 	"github.com/accurics/terrascan/pkg/utils"
 	"github.com/accurics/terrascan/pkg/version"
@@ -55,22 +54,22 @@ func writeSarif(data interface{}, writer io.Writer, forGithub bool) error {
 	report.AddRun(run)
 
 	for _, passedRule := range outputData.PassedRules {
-		m := make(map[string]string)
-		m["category"] = passedRule.Category
-		m["severity"] = passedRule.Severity
+		m := sarif.NewPropertyBag()
+		m.Properties["category"] = passedRule.Category
+		m.Properties["severity"] = passedRule.Severity
 
 		run.AddRule(passedRule.RuleID).
-			WithDescription(passedRule.Description).WithName(passedRule.RuleName).WithProperties(m)
+			WithDescription(passedRule.Description).WithName(passedRule.RuleName).WithProperties(m.Properties)
 	}
 
 	// for each result add the rule, location and result to the report
 	for _, violation := range outputData.Violations {
-		m := make(map[string]string)
-		m["category"] = violation.Category
-		m["severity"] = violation.Severity
+		m := sarif.NewPropertyBag()
+		m.Properties["category"] = violation.Category
+		m.Properties["severity"] = violation.Severity
 
 		rule := run.AddRule(violation.RuleID).
-			WithDescription(violation.Description).WithName(violation.RuleName).WithProperties(m)
+			WithDescription(violation.Description).WithName(violation.RuleName).WithProperties(m.Properties)
 
 		var artifactLocation *sarif.ArtifactLocation
 
@@ -82,7 +81,11 @@ func writeSarif(data interface{}, writer io.Writer, forGithub bool) error {
 			if err != nil {
 				return errors.Errorf("unable to create absolute path, error: %v", err)
 			}
-			artifactLocation = sarif.NewSimpleArtifactLocation(fmt.Sprintf("file://%s", absFilePath))
+			uriFilePath, err := utils.GetFileURI(absFilePath)
+			if err != nil {
+				return errors.Errorf("unable to create uri path, error: %v", err)
+			}
+			artifactLocation = sarif.NewSimpleArtifactLocation(uriFilePath)
 		}
 
 		location := sarif.NewLocation().WithPhysicalLocation(sarif.NewPhysicalLocation().
