@@ -24,6 +24,7 @@ import (
 	"os"
 	"path/filepath"
 
+	"github.com/accurics/terrascan/pkg/config"
 	"github.com/accurics/terrascan/pkg/policy"
 	"github.com/accurics/terrascan/pkg/utils"
 	scanUtils "github.com/accurics/terrascan/test/e2e/scan"
@@ -100,6 +101,17 @@ var _ = Describe("Scan", func() {
 						helper.ContainsDirScanErrorSubString(session, errString2)
 					})
 				})
+				Context("iac loading errors would be displayed in the output, output type is human readable", func() {
+					It("scan the directory and display results", func() {
+						scanArgs := []string{scanUtils.ScanCommand, "-p", policyRootRelPath}
+						// these errors would come from terraform, helm, and kustomize iac providers
+						errString1 := "kustomization.y(a)ml file not found in the directory"
+						errString2 := "no helm charts found in directory"
+						session = helper.RunCommand(terrascanBinaryPath, outWriter, errWriter, scanArgs...)
+						helper.ContainsDirScanErrorSubString(session, errString1)
+						helper.ContainsDirScanErrorSubString(session, errString2)
+					})
+				})
 				When("iac type is terraform and --non-recursive flag is used", func() {
 					It("should error out if no terraform files are present in working directory", func() {
 						scanArgs := []string{scanUtils.ScanCommand, "-i", "terraform", "--non-recursive"}
@@ -345,4 +357,23 @@ var _ = Describe("Scan", func() {
 			})
 		})
 	})
+	Describe("terrascan scan command run with policy-path", func() {
+		Context("terrascan scan command is run with --p flag", func() {
+			It("should scan and should use provided policies without downloading any from default repo", func() {
+				if path, err := os.Stat(config.GetPolicyRepoPath()); err == nil && path.IsDir() {
+					os.RemoveAll(config.GetPolicyRepoPath())
+				}
+				iacDir, err1 := filepath.Abs(filepath.Join(awsIacRelPath, "aws_ami_violation"))
+				policyDir, err2 := filepath.Abs(policyRootRelPath)
+				Expect(err1).NotTo(HaveOccurred())
+				Expect(err2).NotTo(HaveOccurred())
+				scanArgs := []string{"scan", "-p", policyDir, "-i", "terraform", "-d", iacDir}
+				session := helper.RunCommand(terrascanBinaryPath, outWriter, errWriter, scanArgs...)
+				Eventually(session, 3).Should(gexec.Exit(helper.ExitCodeThree))
+				_, err := os.Stat(config.GetPolicyRepoPath())
+				Expect(err).To(HaveOccurred())
+				Expect(err.Error()).To(ContainSubstring("no such file or directory"))
+			})
+		})
+	})
 })
